Interval

Struct Interval 

pub struct Interval { /* private fields */ }
An interval represents the start (0-based, inclusive) and end (0-based exclusive) ranges of the query.

Implementations

Source

impl Interval

pub fn contains_interval(&self, other: Interval) -> Option<Self>

Does this interval contain the passed in interval. Returns the passed in interval if true.

pub fn constraint_interval(&self, other: Interval) -> Option<Self>

Constraint this interval so that it contains the maximum overlapping region between the two intervals. This will reduce the range of either interval so that the returned interval contains start and end ranges valid to both intervals. No interval is returned if there are no valid ranges.

pub fn order_by_range(&self, other: &Interval) -> Ordering

Order the interval with another interval based on the range that either specify. The interval with the larger range (end - start) is considered greater.

pub fn is_valid(&self) -> bool

Is this a valid interval, i.e. is the start range less than the end range.

pub fn contains(&self, value: u32) -> bool

Check if this interval contains the value.

pub fn into_one_based(self) -> Result<NoodlesInterval>

Convert this interval into a one-based noodles Interval.

pub fn convert_start(start: u32) -> Result<Position>

Convert a start position to a noodles Position.

pub fn convert_end(end: u32) -> Result<Position>

Convert an end position to a noodles Position.

pub fn convert_position<F>(value: u32, convert_fn: F) -> Result<Position>
where F: FnOnce(u32) -> Result<u32>,

Convert a u32 position to a noodles Position.

pub fn start(&self) -> Option<u32>

Start position.

pub fn end(&self) -> Option<u32>

End position.

pub fn new(start: Option<u32>, end: Option<u32>) -> Self

Create a new interval