Struct htsget_config::types::Query

source ·
pub struct Query { /* private fields */ }
A query contains all the parameters that can be used when requesting a search for either of reads or variants.

Implementations

source

impl Query

source

pub fn new(id: impl Into<String>, format: Format) -> Self

source

pub fn set_id(&mut self, id: impl Into<String>)

source

pub fn with_id(self, id: impl Into<String>) -> Self

source

pub fn with_format(self, format: Format) -> Self

source

pub fn with_class(self, class: Class) -> Self

source

pub fn with_reference_name(self, reference_name: impl Into<String>) -> Self

source

pub fn with_start(self, start: u32) -> Self

source

pub fn with_end(self, end: u32) -> Self

source

pub fn with_fields(self, fields: Fields) -> Self

source

pub fn with_tags(self, tags: Tags) -> Self

source

pub fn with_no_tags(self, no_tags: Vec<impl Into<String>>) -> Self

source

pub fn id(&self) -> &str

source

pub fn format(&self) -> Format

source

pub fn class(&self) -> Class

source

pub fn reference_name(&self) -> Option<&str>

source

pub fn interval(&self) -> Interval

source

pub fn fields(&self) -> &Fields

source

pub fn tags(&self) -> &Tags

source

pub fn no_tags(&self) -> &NoTags