pub struct Resolver { /* private fields */ }
A regex storage is a storage that matches ids using Regex.

Implementations

source

impl Resolver

source

pub fn new( storage: Storage, regex: &str, replacement_string: &str, allow_guard: AllowGuard ) -> Result<Self, Error>

Create a new regex storage.

source

pub fn resolvers_from_data_server_config(&mut self, config: &DataServerConfig)

Set the local resolvers from the data server config.

source

pub fn regex(&self) -> &Regex

Get the regex.

source

pub fn substitution_string(&self) -> &str

Get the substitution string.

source

pub fn allow_guard(&self) -> &AllowGuard

Get the query guard.

source

pub fn storage(&self) -> &Storage

Get the storage backend.

source

pub fn allow_formats(&self) -> &[Format]

Get allow formats.

source

pub fn allow_classes(&self) -> &[Class]

Get allow classes.

source

pub fn allow_interval(&self) -> Interval

Get allow interval.

source

pub fn allow_reference_names(&self) -> &ReferenceNames

Get allow reference names.

source

pub fn allow_fields(&self) -> &Fields

Get allow fields.

source

pub fn allow_tags(&self) -> &Tags

Get allow tags.