pub struct Interval { /* private fields */ }Expand description
An interval represents the start (0-based, inclusive) and end (0-based exclusive) ranges of the query.
Implementations
Sourceimpl Interval
impl Interval
Sourcepub fn contains_interval(&self, other: Interval) -> Option<Self>
pub fn contains_interval(&self, other: Interval) -> Option<Self>
Does this interval contain the passed in interval. Returns the passed in interval if true.
Sourcepub fn constraint_interval(&self, other: Interval) -> Option<Self>
pub fn constraint_interval(&self, other: Interval) -> Option<Self>
Constraint this interval so that it contains the maximum overlapping region between the two intervals. This will reduce the range of either interval so that the returned interval contains start and end ranges valid to both intervals. No interval is returned if there are no valid ranges.
Sourcepub fn order_by_range(&self, other: &Interval) -> Ordering
pub fn order_by_range(&self, other: &Interval) -> Ordering
Order the interval with another interval based on the range that either specify. The interval with the larger range (end - start) is considered greater.
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Is this a valid interval, i.e. is the start range less than the end range.
Sourcepub fn into_one_based(self) -> Result<NoodlesInterval>
pub fn into_one_based(self) -> Result<NoodlesInterval>
Convert this interval into a one-based noodles Interval.
Sourcepub fn convert_start(start: u32) -> Result<Position>
pub fn convert_start(start: u32) -> Result<Position>
Convert a start position to a noodles Position.
Sourcepub fn convert_end(end: u32) -> Result<Position>
pub fn convert_end(end: u32) -> Result<Position>
Convert an end position to a noodles Position.
Sourcepub fn convert_position<F>(value: u32, convert_fn: F) -> Result<Position>
pub fn convert_position<F>(value: u32, convert_fn: F) -> Result<Position>
Convert a u32 position to a noodles Position.